==> pipewire-docs-1:1.2.7-1-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/search/variables_2.js <==
var searchData=
[
  ['b_0',['b',['../structspa__pod__dynamic__builder.html#add3ef12e6da96cfb988c0672119a7ac1',1,'spa_pod_dynamic_builder']]],
  ['band_5fmode_1',['band_mode',['../structspa__audio__info__amr.html#a42ebba3d8e2cdd474ef49fb4c4c6b0f4',1,'spa_audio_info_amr']]],
  ['bar_2',['bar',['../structspa__io__segment.html#ad525d9a6f0185e329abc7e89fe394cfd',1,'spa_io_segment']]],
  ['bar_5fstart_5ftick_3',['bar_start_tick',['../structspa__io__segment__bar.html#ad1c1cb6cda52db4b3ffbb4dbee804bb0',1,'spa_io_segment_bar']]],
  ['beat_4',['beat',['../structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5',1,'spa_io_segment_bar']]],
  ['before_5',['before',['../structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20',1,'spa_loop_control_hooks']]],
  ['begin_6',['begin',['../structspa__ratelimit.html#a9b0862c9c1b74066994419ce0957b43b',1,'spa_ratelimit']]],
  ['begin_5fproxy_7',['begin_proxy',['../structpw__protocol__native__ext.html#a3de6ba89d6e099eee955acf2744a52da',1,'pw_protocol_native_ext']]],
  ['begin_5fresource_8',['begin_resource',['../structpw__protocol__native__ext.html#a9c23c3dab6c416b7f92e3b3684ddae88',1,'pw_protocol_native_ext']]],
  ['bind_9',['bind',['../structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a',1,'pw_registry_methods']]],
  ['bitmap_5foffset_10',['bitmap_offset',['../structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0',1,'spa_meta_cursor']]],
  ['bitorder_11',['bitorder',['../structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170',1,'spa_audio_info_dsd']]],
  ['bitrate_12',['bitrate',['../structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2',1,'spa_audio_info_aac::bitrate'],['../structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2',1,'spa_audio_info_wma::bitrate']]],
  ['block_13',['block',['../structpw__memmap.html#ae80282a00a02c34be7f36975ea52768b',1,'pw_memmap']]],
  ['block_5falign_14',['block_align',['../structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55',1,'spa_audio_info_wma']]],
  ['body_15',['body',['../structspa__command__body.html#ab477c03f242e4d10ed2a4e7057f52123',1,'spa_command_body::body'],['../structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e',1,'spa_command::body'],['../structspa__event__body.html#aa484bc2cadd16a104476183666de3819',1,'spa_event_body::body'],['../structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb',1,'spa_event::body'],['../structspa__pod__array.html#a30a4ff74b448da3df862a7bdb20dad04',1,'spa_pod_array::body'],['../structspa__pod__choice.html#aa9927ee9a4a320384560480e1783705c',1,'spa_pod_choice::body'],['../structspa__pod__object.html#a5432f079d6ffcb0d2f0baee8a130219a',1,'spa_pod_object::body'],['../structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7',1,'spa_pod_pointer::body'],['../structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163',1,'spa_pod_sequence::body']]],
  ['bound_16',['bound',['../structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14',1,'pw_proxy_events']]],
  ['bound_5fid_17',['bound_id',['../structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976',1,'pw_core_events']]],
  ['bound_5fprops_18',['bound_props',['../structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e',1,'pw_core_events::bound_props'],['../structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158',1,'pw_proxy_events::bound_props']]],
  ['bpm_19',['bpm',['../structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3',1,'spa_io_segment_bar']]],
  ['buffer_20',['buffer',['../structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090',1,'pw_buffer::buffer'],['../structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3',1,'pw_client_node_buffer::buffer'],['../structspa__strbuf.html#ad1ee23ef60728cefba6d11341da61ef1',1,'spa_strbuf::buffer']]],
  ['buffer_5fid_21',['buffer_id',['../structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b',1,'spa_io_buffers']]],
  ['buffered_22',['buffered',['../structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff',1,'pw_time']]],
  ['buffers_23',['buffers',['../structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed',1,'pw_buffers::buffers'],['../structspa__io__async__buffers.html#a97004192f552cb50fee39067e5b07fff',1,'spa_io_async_buffers::buffers']]],
  ['builder_24',['builder',['../structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce',1,'spa_result_device_params_data::builder'],['../structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c',1,'spa_result_node_params_data::builder']]],
  ['burst_25',['burst',['../structspa__ratelimit.html#af29b16a4c28de3a2503ae1302dba9ff7',1,'spa_ratelimit']]],
  ['busy_5fchanged_26',['busy_changed',['../structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee',1,'pw_impl_client_events']]],
  ['bw_27',['bw',['../structspa__dll.html#ac3de731c327763f69c44e98224ee1068',1,'spa_dll']]]
];

==> pipewire-docs-1:1.4.10-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/search/variables_2.js <==
var searchData=
[
  ['b_0',['b',['../structspa__pod__dynamic__builder.html#add3ef12e6da96cfb988c0672119a7ac1',1,'spa_pod_dynamic_builder']]],
  ['band_5fmode_1',['band_mode',['../structspa__audio__info__amr.html#a42ebba3d8e2cdd474ef49fb4c4c6b0f4',1,'spa_audio_info_amr']]],
  ['bar_2',['bar',['../structspa__io__segment.html#ad525d9a6f0185e329abc7e89fe394cfd',1,'spa_io_segment']]],
  ['bar_5fstart_5ftick_3',['bar_start_tick',['../structspa__io__segment__bar.html#ad1c1cb6cda52db4b3ffbb4dbee804bb0',1,'spa_io_segment_bar']]],
  ['beat_4',['beat',['../structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5',1,'spa_io_segment_bar']]],
  ['before_5',['before',['../structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20',1,'spa_loop_control_hooks']]],
  ['begin_6',['begin',['../structspa__ratelimit.html#a9b0862c9c1b74066994419ce0957b43b',1,'spa_ratelimit']]],
  ['begin_5fproxy_7',['begin_proxy',['../structpw__protocol__native__ext.html#a3de6ba89d6e099eee955acf2744a52da',1,'pw_protocol_native_ext']]],
  ['begin_5fresource_8',['begin_resource',['../structpw__protocol__native__ext.html#a9c23c3dab6c416b7f92e3b3684ddae88',1,'pw_protocol_native_ext']]],
  ['bind_9',['bind',['../structpw__registry__methods.html#a743174c4df93282f1361f137383cb41a',1,'pw_registry_methods']]],
  ['bitmap_5foffset_10',['bitmap_offset',['../structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0',1,'spa_meta_cursor']]],
  ['bitorder_11',['bitorder',['../structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170',1,'spa_audio_info_dsd']]],
  ['bitrate_12',['bitrate',['../structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2',1,'spa_audio_info_aac::bitrate'],['../structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2',1,'spa_audio_info_wma::bitrate']]],
  ['block_13',['block',['../structpw__memmap.html#ae80282a00a02c34be7f36975ea52768b',1,'pw_memmap']]],
  ['block_5falign_14',['block_align',['../structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55',1,'spa_audio_info_wma']]],
  ['body_15',['body',['../structspa__command__body.html#ab477c03f242e4d10ed2a4e7057f52123',1,'spa_command_body::body'],['../structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e',1,'spa_command::body'],['../structspa__event__body.html#aa484bc2cadd16a104476183666de3819',1,'spa_event_body::body'],['../structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb',1,'spa_event::body'],['../structspa__pod__array.html#a30a4ff74b448da3df862a7bdb20dad04',1,'spa_pod_array::body'],['../structspa__pod__choice.html#aa9927ee9a4a320384560480e1783705c',1,'spa_pod_choice::body'],['../structspa__pod__object.html#a5432f079d6ffcb0d2f0baee8a130219a',1,'spa_pod_object::body'],['../structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7',1,'spa_pod_pointer::body'],['../structspa__pod__sequence.html#ad699555cf7c8114347524399f2a8b163',1,'spa_pod_sequence::body']]],
  ['bound_16',['bound',['../structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14',1,'pw_proxy_events']]],
  ['bound_5fid_17',['bound_id',['../structpw__core__events.html#aab9b9d3a84837d892a4617c29f03e976',1,'pw_core_events']]],
  ['bound_5fprops_18',['bound_props',['../structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e',1,'pw_core_events::bound_props'],['../structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158',1,'pw_proxy_events::bound_props']]],
  ['bpm_19',['bpm',['../structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3',1,'spa_io_segment_bar']]],
  ['buffer_20',['buffer',['../structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090',1,'pw_buffer::buffer'],['../structpw__client__node__buffer.html#a27039caf89b376d354a33d1559e939b3',1,'pw_client_node_buffer::buffer'],['../structspa__strbuf.html#ad1ee23ef60728cefba6d11341da61ef1',1,'spa_strbuf::buffer'],['../group__pw__core.html#ga0ed1316569a083925a39be8454e714bb',1,'buffer:&#160;core.h']]],
  ['buffer_5fid_21',['buffer_id',['../structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b',1,'spa_io_buffers']]],
  ['buffered_22',['buffered',['../structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff',1,'pw_time']]],
  ['buffers_23',['buffers',['../structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed',1,'pw_buffers::buffers'],['../structspa__io__async__buffers.html#a97004192f552cb50fee39067e5b07fff',1,'spa_io_async_buffers::buffers']]],
  ['builder_24',['builder',['../structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce',1,'spa_result_device_params_data::builder'],['../structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c',1,'spa_result_node_params_data::builder']]],
  ['burst_25',['burst',['../structspa__ratelimit.html#af29b16a4c28de3a2503ae1302dba9ff7',1,'spa_ratelimit']]],
  ['busy_5fchanged_26',['busy_changed',['../structpw__impl__client__events.html#a046e956441b5395308c8ff140292dfee',1,'pw_impl_client_events']]],
  ['bw_27',['bw',['../structspa__dll.html#ac3de731c327763f69c44e98224ee1068',1,'spa_dll']]]
];
